@@ -79,7 +79,7 @@ learner_args <- list(
 # required for mlexperiments::MLCrossValidation and
 # mlexperiments::MLNestedCV
 predict_args <- list(reshape = TRUE)
-performance_metric <- metric("bacc")
+performance_metric <- metric("ACC")
 performance_metric_args <- NULL
 return_models <- FALSE
 
@@ -238,9 +238,9 @@ validator_results <- validator$execute()
 
 head(validator_results)
 #>     fold performance subsample colsample_bytree min_child_weight learning_rate max_depth nrounds      objective eval_metric
-#> 1: Fold1   0.4685501 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
-#> 2: Fold2   0.4179775 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
-#> 3: Fold3   0.4718162 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
+#> 1: Fold1   0.5645161 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
+#> 2: Fold2   0.5195682 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
+#> 3: Fold3   0.5618280 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
 #>    num_class
 #> 1:         3
 #> 2:         3
@@ -310,9 +310,9 @@ validator_results <- validator$execute()
 
 head(validator_results)
 #>     fold performance nrounds subsample colsample_bytree min_child_weight learning_rate max_depth      objective eval_metric
-#> 1: Fold1   0.4304667      30       0.8              0.8                5           0.1         5 multi:softprob    mlogloss
-#> 2: Fold2   0.3907826      33       0.8              0.8                5           0.1         5 multi:softprob    mlogloss
-#> 3: Fold3   0.4183769      25       0.6              1.0                1           0.1         5 multi:softprob    mlogloss
+#> 1: Fold1   0.5658602      30       0.8              0.8                5           0.1         5 multi:softprob    mlogloss
+#> 2: Fold2   0.5276653      33       0.8              0.8                5           0.1         5 multi:softprob    mlogloss
+#> 3: Fold3   0.5470430      25       0.6              1.0                1           0.1         5 multi:softprob    mlogloss
 #>    num_class
 #> 1:         3
 #> 2:         3
@@ -367,9 +367,9 @@ validator_results <- validator$execute()
 
 head(validator_results)
 #>     fold performance subsample colsample_bytree min_child_weight learning_rate max_depth nrounds      objective eval_metric
-#> 1: Fold1   0.4607781 0.7285277        0.8178568                1     0.1099728        10      18 multi:softprob    mlogloss
-#> 2: Fold2   0.4306211 0.5578915        0.7352097                1     0.1099728        10      24 multi:softprob    mlogloss
-#> 3: Fold3   0.4464739 0.5001911        0.8708509                1     0.1099728        10      19 multi:softprob    mlogloss
+#> 1: Fold1   0.5524194 0.7285277        0.8178568                1     0.1099728        10      18 multi:softprob    mlogloss
+#> 2: Fold2   0.5330634 0.5578915        0.7352097                1     0.1099728        10      24 multi:softprob    mlogloss
+#> 3: Fold3   0.5456989 0.5001911        0.8708509                1     0.1099728        10      19 multi:softprob    mlogloss
 #>    num_class
 #> 1:         3
 #> 2:         3
@@ -391,9 +391,9 @@ perf_xgboost <- mlexperiments::performance(
 )
 perf_xgboost
 #>    model performance
-#> 1: Fold1   0.4628262
-#> 2: Fold2   0.4503222
-#> 3: Fold3   0.4535445
+#> 1: Fold1   0.5621735
+#> 2: Fold2   0.5475444
+#> 3: Fold3   0.5464995
 
 
 ## -----------------------------------------------------------------------------
@@ -456,7 +456,7 @@ head(tuner_results_grid)
 
 
 ## -----------------------------------------------------------------------------
-validator <- mlexperiments::MLCrossValidation$new(
+validator_w_weights <- mlexperiments::MLCrossValidation$new(
   learner = mllrnrs::LearnerXgboost$new(
     metric_optimization_higher_better = FALSE
   ),
@@ -466,22 +466,21 @@ validator <- mlexperiments::MLCrossValidation$new(
 )
 
 # append the optimized setting from above with the newly created weights
-validator$learner_args <- c(
-  tuner$results$best.setting[-1],
-  list("case_weights" = y_weights)
+validator_w_weights$learner_args <- c(
+  tuner_w_weights$results$best.setting[-1]
 )
 
-validator$predict_args <- predict_args
-validator$performance_metric <- performance_metric
-validator$performance_metric_args <- performance_metric_args
-validator$return_models <- return_models
+validator_w_weights$predict_args <- predict_args
+validator_w_weights$performance_metric <- performance_metric
+validator_w_weights$performance_metric_args <- performance_metric_args
+validator_w_weights$return_models <- return_models
 
-validator$set_data(
+validator_w_weights$set_data(
   x = train_x,
   y = train_y
 )
 
-validator_results <- validator$execute()
+validator_results <- validator_w_weights$execute()
 #> 
 #> CV fold: Fold1
 #> 
@@ -492,16 +491,11 @@ validator_results <- validator$execute()
 #>                                                                                                                                   
 
 head(validator_results)
-#>      fold performance subsample colsample_bytree min_child_weight learning_rate max_depth nrounds      objective eval_metric
-#>    <char>       <num>     <num>            <num>            <num>         <num>     <num>   <int>         <char>      <char>
-#> 1:  Fold1   0.4508447 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
-#> 2:  Fold2   0.4185381 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
-#> 3:  Fold3   0.4436661 0.5356077        0.8312972                1     0.1099728        10      23 multi:softprob    mlogloss
-#>    num_class
-#>        <num>
-#> 1:         3
-#> 2:         3
-#> 3:         3
+#>      fold performance nrounds subsample colsample_bytree min_child_weight learning_rate max_depth      objective eval_metric num_class
+#>    <char>       <num>   <int>     <num>            <num>            <num>         <num>     <num>         <char>      <char>     <num>
+#> 1:  Fold1   0.5631720      46       0.8              0.8                5           0.1         5 multi:softprob    mlogloss         3
+#> 2:  Fold2   0.5222672      46       0.8              0.8                5           0.1         5 multi:softprob    mlogloss         3
+#> 3:  Fold3   0.5510753      46       0.8              0.8                5           0.1         5 multi:softprob    mlogloss         3
 
 
 ## ----include=FALSE------------------------------------------------------------
